summaryrefslogtreecommitdiffstats
path: root/chromium/media/audio/fake_audio_consumer.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/media/audio/fake_audio_consumer.h')
-rw-r--r--chromium/media/audio/fake_audio_consumer.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/chromium/media/audio/fake_audio_consumer.h b/chromium/media/audio/fake_audio_consumer.h
index 50373565d00..18c552ad97b 100644
--- a/chromium/media/audio/fake_audio_consumer.h
+++ b/chromium/media/audio/fake_audio_consumer.h
@@ -10,7 +10,7 @@
#include "media/base/media_export.h"
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
}
namespace media {
@@ -21,12 +21,13 @@ class AudioParameters;
// simulate a real time consumer of audio data.
class MEDIA_EXPORT FakeAudioConsumer {
public:
// |worker_loop| is the loop on which the ReadCB provided to Start() will be
// executed on. This may or may not be the be for the same thread that
// invokes the Start/Stop methods.
// |params| is used to determine the frequency of callbacks.
- FakeAudioConsumer(const scoped_refptr<base::MessageLoopProxy>& worker_loop,
- const AudioParameters& params);
+ FakeAudioConsumer(
+ const scoped_refptr<base::SingleThreadTaskRunner>& worker_task_runner,
+ const AudioParameters& params);
~FakeAudioConsumer();
// Start executing |read_cb| at a regular intervals. Stop() must be called by
@@ -21,12 +21,13 @@ class AudioParameters;
class MEDIA_EXPORT FakeAudioConsumer {
public:
- // |worker_loop| is the loop on which the ReadCB provided to Start() will be
- // executed on. This may or may not be the be for the same thread that
- // invokes the Start/Stop methods.
+ // |worker_task_runner| is the task runner on which the ReadCB provided to
+ // Start() will be executed on. This may or may not be the be for the same
+ // thread that invokes the Start/Stop methods.
// |params| is used to determine the frequency of callbacks.